src/pyams_content/component/paragraph/zmi/html.py
changeset 487 093f201e3168
parent 446 4ce676e4859f
child 497 32f7f9950df3
--- a/src/pyams_content/component/paragraph/zmi/html.py	Thu Mar 15 12:06:23 2018 +0100
+++ b/src/pyams_content/component/paragraph/zmi/html.py	Fri Mar 16 08:17:54 2018 +0100
@@ -20,7 +20,7 @@
 from pyams_content.component.association.zmi.interfaces import IAssociationsParentForm
 from pyams_content.component.illustration.interfaces import IIllustration
 from pyams_content.component.paragraph.interfaces import IParagraphContainerTarget, IParagraphFactorySettings, \
-    IParagraphContainer, IParagraphPreview
+    IParagraphContainer, IParagraphRenderer
 from pyams_content.component.paragraph.interfaces.html import IHTMLParagraph, IRawParagraph, RAW_PARAGRAPH_TYPE, \
     HTML_PARAGRAPH_TYPE
 from pyams_content.component.paragraph.zmi.interfaces import IParagraphInnerEditor, IParagraphContainerView
@@ -160,13 +160,13 @@
 
 
 #
 # Raw HTML paragraph preview
 #
 
-@adapter_config(context=(IRawParagraph, IPyAMSLayer), provides=IParagraphPreview)
-@template_config(template='templates/raw-preview.pt', layer=IPyAMSLayer)
-class RawParagraphPreview(BaseContentProvider):
-    """Raw HTML paragraph preview"""
+@adapter_config(context=(IRawParagraph, IPyAMSLayer), provides=IParagraphRenderer)
+@template_config(template='templates/raw-render.pt', layer=IPyAMSLayer)
+class RawParagraphRenderer(BaseContentProvider):
+    """Raw HTML paragraph renderer"""
 
     language = None
 
@@ -340,13 +340,13 @@
 
 
 #
 # Rich text paragraph preview
 #
 
-@adapter_config(context=(IHTMLParagraph, IPyAMSLayer), provides=IParagraphPreview)
-@template_config(template='templates/html-preview.pt', layer=IPyAMSLayer)
-class HTMLParagraphPreview(BaseContentProvider):
-    """Rich text paragraph preview"""
+@adapter_config(context=(IHTMLParagraph, IPyAMSLayer), provides=IParagraphRenderer)
+@template_config(template='templates/html-render.pt', layer=IPyAMSLayer)
+class HTMLParagraphRenderer(BaseContentProvider):
+    """Rich text paragraph renderer"""
 
     illustration = None
     illustration_renderer = None
@@ -160,13 +160,13 @@
 
 #
-# Raw HTML paragraph preview
+# Raw HTML paragraph renderer
 #
 
@@ -340,13 +340,13 @@
 
 #
-# Rich text paragraph preview
+# Rich text paragraph renderer
 #
 